aboutsummaryrefslogtreecommitdiffhomepage
path: root/tests
diff options
context:
space:
mode:
authorGravatar joshualitt <joshualitt@google.com>2015-02-25 13:04:43 -0800
committerGravatar Commit bot <commit-bot@chromium.org>2015-02-25 13:04:44 -0800
commit2907059d0eb1972a300ea1bf0cd4e4febabb9784 (patch)
treef3f565626302891f0b74b870972ae2a4db89df4c /tests
parentedeccc58606e0421a1ae275e391ee4347c6f52f6 (diff)
Revert of Pass clip to context (patchset #8 id:180001 of https://codereview.chromium.org/936943002/)
Reason for revert: Strange blur problems on nexus 5 Original issue's description: > I'd really like to land this before the branch so speedy reviews are appreciated. > > BUG=skia: > > Committed: https://skia.googlesource.com/skia/+/586d5d640b19860dfbbd903a5188da1bbbe87336 TBR=jvanverth@google.com,senorblanco@google.com,bsalomon@google.com,senorblanco@chromium.org,joshualitt@chromium.org NOPRESUBMIT=true NOTREECHECKS=true NOTRY=true BUG=skia: Review URL: https://codereview.chromium.org/956083002
Diffstat (limited to 'tests')
-rw-r--r--tests/ClipCacheTest.cpp10
-rw-r--r--tests/GLProgramsTest.cpp2
2 files changed, 6 insertions, 6 deletions
diff --git a/tests/GLProgramsTest.cpp b/tests/GLProgramsTest.cpp
index 897e261e5a..d96c56c5e2 100644
--- a/tests/GLProgramsTest.cpp
+++ b/tests/GLProgramsTest.cpp
@@ -247,7 +247,7 @@ bool GrDrawTarget::programUnitTest(int maxStages) {
SkClipStack stack;
stack.clipDevRect(screen, SkRegion::kReplace_Op, false);
- // wrap the SkClipStack in a GrClip
+ // wrap the SkClipStack in a GrClipData
GrClip clip;
clip.setClipStack(&stack);
diff --git a/tests/ClipCacheTest.cpp b/tests/ClipCacheTest.cpp
index 3d3fa95c03..0e5fe1e4ac 100644
--- a/tests/ClipCacheTest.cpp
+++ b/tests/ClipCacheTest.cpp
@@ -84,17 +84,17 @@ static void test_clip_bounds(skiatest::Reporter* reporter, GrContext* context) {
REPORTER_ASSERT(reporter, screen == devStackBounds);
REPORTER_ASSERT(reporter, isIntersectionOfRects);
// wrap the SkClipStack in a GrClip
GrClip clipData;
clipData.setClipStack(&stack);
- SkIRect devGrClipBound;
+ SkIRect devGrClipDataBound;
clipData.getConservativeBounds(texture,
- &devGrClipBound,
+ &devGrClipDataBound,
&isIntersectionOfRects);
- // make sure that GrClip is behaving itself
- REPORTER_ASSERT(reporter, intScreen == devGrClipBound);
+ // make sure that GrClipData is behaving itself
+ REPORTER_ASSERT(reporter, intScreen == devGrClipDataBound);
REPORTER_ASSERT(reporter, isIntersectionOfRects);
}
@@ -84,17 +84,17 @@ static void test_clip_bounds(skiatest::Reporter* reporter, GrContext* context) {
REPORTER_ASSERT(reporter, screen == devStackBounds);
REPORTER_ASSERT(reporter, isIntersectionOfRects);
- // wrap the SkClipStack in a GrClip
+ // wrap the SkClipStack in a GrClipData
GrClip clipData;
clipData.setClipStack(&stack);